@@ -1,4 +1,3 @@
-from io import StringIO
 import allure
 import boto3
 import pandas as pd
@@ -354,28 +353,26 @@ class MyWhatify:
 
     @classmethod
     def ls_client(cls, user_token: str = None):
-        return my_toolkit.UserManagement.get_client_path(user_token=user_token)
+        return my_toolkit.Connector.get_client_path(user_token=user_token)
 
     @classmethod
-    def get_s3_boto_client(cls, user_token: str = None):
-        credentials = my_toolkit.UserManagement.get_credentials(user_token=user_token)
-        s3_client = boto3.client('s3',
-                                 aws_access_key_id=credentials['access_key'],
-                                 aws_secret_access_key=credentials['secret_key'],
-                                 aws_session_token=credentials['session_token'])
-        return s3_client, credentials['bucket'], credentials['path']
+    def get_credentials(cls, api_key: str = None):
+        retval = my_toolkit.Connector.get_credentials(user_token=api_key)
+        return retval
 
     @classmethod
-    def read_to_pandas_df(cls, s3_client, bucket, path):
-        obj = s3_client.get_object(Bucket=bucket, Key=path)
-        df = pd.read_csv(obj['Body'])
+    def get_s3_path(cls, user_token: str = None):
+        return my_toolkit.Connector.get_s3_path(user_token=user_token)
+
+    @classmethod
+    def read_to_pandas_df(cls, user_token: str = None):
+        df = my_toolkit.Connector.read_to_pandas_df(user_token=user_token)
+        print('dele')
         return df
 
     @classmethod
-    def write_pandas_df_to_s3(cls, s3_client, bucket, path, df):
-        csv_buffer = StringIO()
-        df.to_csv(csv_buffer)
-        s3_client.upload_fileobj(csv_buffer, bucket, path)
+    def write_pandas_df_to_s3(cls, df, user_token: str = None):  # s3_client, bucket, path, df):
+        my_toolkit.Connector.write_pandas_df_to_s3(df=df, user_token=user_token)
 
     @classmethod
     def get_pipeline_list(cls, dataset_id, interpt_level=Interpt.PRECISE):
@@ -444,12 +441,6 @@ class MyWhatify:
     #             pass
     #     print('dddd')
 
-    @classmethod
-    def get_credentials(cls, api_key: str = None):
-        retval = my_toolkit.UserManagement.get_credentials(user_token=api_key)
-        return retval
-
-
     #############################
     ###      Validation       ###
     #############################
